@@ -314,8 +314,8 @@ class Model:
         Documentation
         """
         for sizetable in sizetables:
-            for range in self.mergedcells:
-                incell = [range.split(':')[0],range.split(':')[1]]
+            for range in self.__mergedcells:
+                incell = [range.name.split(':')[0],range.name.split(':')[1]]
                 outcell = []
                 for cell in incell:
                     cell_column = cell[0]
@@ -323,9 +323,9 @@ class Model:
                     if cell_row > sizetable[0]:
                         cell_row = cell_row + sizetable[1]
                     outcell.append(cell_column+str(cell_row))
-                self.variable(range).name = outcell[0]+':'+str(outcell[1])
-                self.variable(range).value = outcell[0]+':'+str(outcell[1])
-    return None
+                range.name = outcell[0]+':'+str(outcell[1])
+                range.value = outcell[0]+':'+str(outcell[1])
+        return None
 
     @property
     def variables(self):
